@@ -17,7 +17,8 @@
 # all - trigger "Mark all initial sites or accessible only?"
 # Variables:
 # e0, e1, e2 - linear indexes of sites combinations from 
-#              2D & 3D Moore neighborhood.
+#              2D & 3D Moore neighborhood;
+# b - length of initial sites subset.
 # Value:
 # acc - labeled accessibility matrix for the percolation lattice.
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -26,21 +27,17 @@ ssa2d <- function(x=33,
                   p1=colMeans(matrix(p0[c(
                     1,3, 2,3, 1,4, 2,4)], nrow=2))/2,
                   set=(x^2+1)/2, all=TRUE) {
-  b <- as.integer(length(set))
   e0 <- c(-1, 1,-x, x)
   e1 <- colSums(matrix(e0[c(
     1,3, 2,3, 1,4, 2,4)], nrow=2))
   e <- as.integer(c(e0,e1))
   p <- as.double(c(p0,p1))
   acc <- array(runif(x^2), rep(x,2))
+  if (!all) set <- set[acc[set] < mean(p)]
+  b <- as.integer(length(set))
+  cls <- rep(0L, max(p)*x^2 + b*all)
+  acc[set] <- 2 
   acc[c(1,x),] <- acc[,c(1,x)] <- 1
-  if (all) {
-    cls <- rep(0L, b + max(p)*x^2) 
-    acc[set] <- 2 
-  } else {
-    cls <- rep(0L, max(p)*x^2) 
-    acc[set <- set[acc[set] < mean(p)]] <- 2
-  }
   cls[seq_along(set)] <- as.integer(set - 1)
   .Call("ssTNd", p, acc, b, e, cls) 
   return(acc)
@@ -55,7 +52,6 @@ ssa3d <- function(x=33,
                     1,3,5, 2,3,5, 1,4,5, 2,4,5,
                     1,3,6, 2,3,6, 1,4,6, 2,4,6)], nrow=3))/3,                  
                   set=(x^3+1)/2, all=TRUE) {
-  b <- as.integer(length(set))
   e0 <- c(-1, 1,-x, x,-x^2, x^2)
   e1 <- colSums(matrix(e0[c(
     1,3, 2,3, 1,4, 2,4, 
@@ -67,14 +63,11 @@ ssa3d <- function(x=33,
   e <- as.integer(c(e0,e1,e2))
   p <- as.double(c(p0,p1,p2))
   acc <- array(runif(x^3), rep(x,3))
+  if (!all) set <- set[acc[set] < mean(p)]
+  b <- as.integer(length(set))
+  cls <- rep(0L, max(p)*x^3 + b*all)
+  acc[set] <- 2 
   acc[c(1,x),,] <- acc[,c(1,x),] <- acc[,,c(1,x)] <- 1
-  if (all) {
-    cls <- rep(0L, b + max(p)*x^3) 
-    acc[set] <- 2 
-  } else {
-    cls <- rep(0L, max(p)*x^3) 
-    acc[set <- set[acc[set] < mean(p)]] <- 2
-  }
   cls[seq_along(set)] <- as.integer(set - 1)
   .Call("ssTNd", p, acc, b, e, cls) 
   return(acc)
