@@ -16,14 +16,14 @@
 # all - trigger "Mark all initial sites or accessible only?"
 # Variables:
 # e0, e1, e2 - linear indexes of sites combinations from 
-#              2D & 3D Moore neighborhood.
+#              2D & 3D Moore neighborhood;
+# b - length of initial sites subset.
 # Value:
 # acc - labeled accessibility matrix for the percolation lattice.
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 ssi2d <- function(x=33, 
                   p0=0.5, p1=p0/2, 
                   set=(x^2+1)/2, all=TRUE) {
-  b <- as.integer(length(set))
   e0 <- c(-1, 1,-x, x)
   e1 <- colSums(matrix(e0[c(
     1,3, 2,3, 1,4, 2,4)], nrow=2))
@@ -32,14 +32,11 @@ ssi2d <- function(x=33,
   p1 <- rep(p1, length(e1))
   p <- as.double(c(p0,p1))
   acc <- array(runif(x^2), rep(x,2))
+  if (!all) set <- set[acc[set] < mean(p)]
+  b <- as.integer(length(set))
+  cls <- rep(0L, max(p)*x^2 + b*all)
+  acc[set] <- 2 
   acc[c(1,x),] <- acc[,c(1,x)] <- 1
-  if (all) {
-    cls <- rep(0L, b + max(p)*x^2) 
-    acc[set] <- 2 
-  } else {
-    cls <- rep(0L, max(p)*x^2) 
-    acc[set <- set[acc[set] < mean(p)]] <- 2
-  }
   cls[seq_along(set)] <- as.integer(set - 1)
   .Call("ssTNd", p, acc, b, e, cls) 
   return(acc)
@@ -47,7 +44,6 @@ ssi2d <- function(x=33,
 ssi3d <- function(x=33, 
                   p0=0.2, p1=p0/2, p2=p0/3,
                   set=(x^3+1)/2, all=TRUE) {
-  b <- as.integer(length(set))
   e0 <- c(-1, 1,-x, x,-x^2, x^2)
   e1 <- colSums(matrix(e0[c(
     1,3, 2,3, 1,4, 2,4,
@@ -62,14 +58,11 @@ ssi3d <- function(x=33,
   p2 <- rep(p2, length(e2))
   p <- as.double(c(p0,p1,p2))  
   acc <- array(runif(x^3), rep(x,3))
+  if (!all) set <- set[acc[set] < mean(p)]
+  b <- as.integer(length(set))
+  cls <- rep(0L, max(p)*x^3 + b*all)
+  acc[set] <- 2 
   acc[c(1,x),,] <- acc[,c(1,x),] <- acc[,,c(1,x)] <- 1
-  if (all) {
-    cls <- rep(0L, b + max(p)*x^3) 
-    acc[set] <- 2 
-  } else {
-    cls <- rep(0L, max(p)*x^3) 
-    acc[set <- set[acc[set] < mean(p)]] <- 2
-  }
   cls[seq_along(set)] <- as.integer(set - 1)
   .Call("ssTNd", p, acc, b, e, cls)  
   return(acc)
